"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.stage = void 0;

const fs_extra_1 = require("fs-extra");

const GenerateAppEntryFile_1 = require("./GenerateAppEntryFile");

const constants_1 = require("./constants");

exports.stage = -9;

function addStrictModeRender(api) {
  const isSkip = () => api.userConfig.strictMode !== true;

  api.addImportToAppEntryFile({
    isSkip,
    fn: () => ({
      specifier: '{ StrictMode }',
      source: 'react'
    })
  });
  api.addContainerRenderToAppEntryFile({
    stage: 998,
    isSkip,
    fn: () => `
function renderStrictMode(children?: React.ReactElement) {
  return <StrictMode>{children}</StrictMode>;
}`
  });
}

function addRootContainer(api) {
  api.addImportToAppEntryFile(() => ({
    specifier: 'ReactDOM',
    source: 'react-dom'
  }));
  api.addImportToAppEntryFile(() => ({
    specifier: '{ isFn }',
    source: '@spark-build/web-utils'
  }));
  api.addContainerRenderToAppEntryFile({
    stage: 999,
    fn: () => `
function ReactDOMContainer(ele: React.ReactElement) {
  ReactDOM.render(ele, document.getElementById('root'));
}`
  });
}

async function AppEntryFile(api) {
  api.registerMethod({
    name: 'onGenerateAppEntryFile'
  });
  Object.keys(constants_1.registerMethodKeys).forEach(name => {
    api.registerMethod({
      name
    });
  });
  console.log('addStrictModeRender', 'addRootContainer');
  addStrictModeRender(api);
  addRootContainer(api);
  api.onGenerateAppEntryFile(async () => {
    const filePath = api.resolveSrcPath('main.tsx');
    const content = await GenerateAppEntryFile_1.GenerateAppEntryFile.run(api);
    return fs_extra_1.outputFile(filePath, content).then(() => api.prettier.addPrettierFile(filePath));
  });
}

exports.default = AppEntryFile;