"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GenerateFile = void 0;

const tslib_1 = require("tslib");

const path_1 = require("path");

const fs_extra_1 = require("fs-extra");

const Mustache = tslib_1.__importStar(require("mustache"));

class GenerateFile {
  constructor(server) {
    this.generateFileQueue = [];
    this.server = server;
  }

  addGenerateFileToQueue(opt) {
    this.generateFileQueue.push(opt);
    return this;
  }

  copyFile(src, dest) {
    return fs_extra_1.copy(src, dest);
  }

  readTplFile(...filePath) {
    return fs_extra_1.readFileSync(path_1.join(...filePath), 'utf-8');
  }

  renderTpl(content, view) {
    return Mustache.render(content, view);
  }

  outputFile(f, c) {
    return fs_extra_1.outputFile(f, c, 'utf-8');
  }

  async runGenerateFileQueue() {
    if (!this.generateFileQueue.length) {
      return undefined;
    }

    return Promise.all(this.generateFileQueue.map(item => this.outputFile(item.path, item.content))).then(() => {
      this.generateFileQueue = [];
    });
  }

  async removeTmpFile(path) {
    const filePath = this.server.resolveTmpPath(path);
    return fs_extra_1.existsSync(filePath) ? fs_extra_1.remove(filePath) : true;
  }

  async writeFile({
    path,
    content,
    isPrettier
  }) {
    const filePath = this.server.resolveTmpPath(path);

    if (fs_extra_1.existsSync(filePath) && fs_extra_1.readFileSync(filePath, 'utf-8') === content) {
      return false;
    }

    await this.outputFile(filePath, content);

    if (isPrettier) {
      this.server.prettier.addPrettierFile(filePath);
    }

    return true;
  }

}

exports.GenerateFile = GenerateFile;