"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PrettierFiles = void 0;

const tslib_1 = require("tslib");

const fs = tslib_1.__importStar(require("fs-extra"));

const util_1 = require("../../util");

class PrettierFiles {
  constructor(server) {
    this.files = [];
    this.isConsoleLog = true;
    this.server = server;
  }

  setConsoleLog(t) {
    this.isConsoleLog = t;
    return this;
  }

  addPrettierFile(file) {
    this.files.push(file);
    return this;
  }

  reset() {
    this.files = [];
  }

  async isExistSparkBuildLintDep() {
    const pkg = await fs.readJson(this.server.resolveRootPath('package.json'));
    const deps = pkg.devDependencies || pkg.dependencies;
    return (deps === null || deps === void 0 ? void 0 : deps['@spark-build/lint']) ? Promise.resolve() : Promise.reject();
  }

  async isExistPrettierFile() {
    const rootFiles = await fs.readdir(this.server.paths.cwd);
    return new Promise((r, j) => {
      rootFiles.some(n => n.indexOf('prettier') !== -1) ? r(undefined) : j();
    });
  }

  async canItBePrettier() {
    return this.isExistPrettierFile();
  }

  prettier(filePath) {
    return util_1.exec(`yarn prettier --config .prettierrc.js --write ${filePath}`, this.isConsoleLog);
  }

  async run() {
    if (!this.files.length) {
      return undefined;
    }

    return this.canItBePrettier().then(() => Promise.all([...new Set(this.files)].map(f => this.prettier(f)))).then(() => this.reset());
  }

}

exports.PrettierFiles = PrettierFiles;